"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reject = exports.resolve = exports.add = void 0;
const promises = {};
function add(id, resolve, reject) {
    if (promises[id]) {
        throw new Error("Already have promise with id " + id);
    }
    promises[id] = { resolve, reject };
}
exports.add = add;
function resolve(id, args) {
    const promise = getAndRemovePromise(id);
    if (!promise) {
        return false;
    }
    promise.resolve(args);
    return true;
}
exports.resolve = resolve;
function reject(id, args) {
    const promise = getAndRemovePromise(id);
    if (!promise) {
        return false;
    }
    promise.reject(args);
    return true;
}
exports.reject = reject;
function promised(id) {
    return promises[id] !== undefined;
}
function getAndRemovePromise(id) {
    const promise = promises[id];
    if (!promise) {
        return;
    }
    delete promises[id];
    return promise;
}
exports.default = {
    add,
    resolve,
    reject,
    promised
};
//# sourceMappingURL=promises.js.map